<?php

namespace Drupal\syncart\Hook;

/**
 * Hook form alter.
 */
class FormVariationAlter {

  /**
   * Implements hook_form_alter().
   */
  public static function hook(&$form, &$form_state) {
    $forms_ids = [
      'commerce_product_product_edit_form',
      'commerce_product_product_add_form',
      'commerce_product_variation_variation_add_form',
      'commerce_product_variation_variation_edit_form',
    ];
    if (in_array($form['#form_id'], $forms_ids)) {
      $form['#validate'][] = [self::class,'customFormValidation'];
    }
  }

  /**
   * Form Validation.
   */
  public static function customFormValidation(&$form, &$form_state) {
    $entity_manager = \Drupal::entityTypeManager();
    $route_match = \Drupal::routeMatch();
    $params = $route_match->getParameters();
    $product = $params->get('commerce_product') ?? [];
    if (empty($product)) {
      return;
    }
    $stores = $product->getStores();
    if (empty($stores)) {
      $store = $entity_manager->getStorage('commerce_store')->loadDefault();
    }
    else {
      $store = array_shift($stores);
    }
    if (empty($store)) {
      return;
    }
    $store_currency_code = $store->getDefaultCurrencyCode();
    $field_name = 'price';
    $price = $form_state->getValue($field_name);
    if (empty($price)) {
      $field_name = 'variations';
      $variations = $form_state->getValue($field_name);
      if (!empty($variations) && isset($variations['entity'])) {
        $price = $variations['entity']['price'];
      }
      else {
        return;
      }
    }
    $price = array_shift($price);
    $variation_currency_code = $price['currency_code'];
    if ($variation_currency_code != $store_currency_code) {
      $form_state->setErrorByName(
        $field_name,
        t('Invalid currency selected. Should be @currency.',
        ['@currency' => $store_currency_code])
      );
    }
  }

}
